// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	BoresightCcf.cc: - implementation of BoresightCcf class
//
//	AUTHOR:
//		U. Lammers, Tue May 20 17:49:54 MEST 2003
//
//	$Header: /sasbuild/sas_git_repo/cvs_copy/sasdev/sas/packages/ccftools/bscalgen/src/BoresightCcf.cc,v 1.1 2003/05/23 16:26:14 ulammers Exp $
//
#include <cstring>

#include "BoresightCcf.h"

void BoresightCcf::createAndFinalize(Xmm::Instrument instrument,
									 const EulerAngles &bsAngles)
{
	DataSet *set = dataSetServer->open(_name, DataSet::Create);
	*set->addAttribute("TELESCOP") = "XMM";
	*set->addAttribute("SCOPE") = "XMM";
	*set->addAttribute("TYPEID") = "BORESIGHT";
	*set->addAttribute("ISSUE") = 1;
	*set->addAttribute("VALDATE") = Xmm::missionStartTime.toString();
	*set->addAttribute("CATEGORY") = "XMMCCF";
	*set->addAttribute("EXTSEQID") = "BORESIGHT";
	*set->addAttribute("EXTSEQU") = "ANY";
	*set->addAttribute("SUBDATE") = STime::currentTime().toString();

	unsigned N = instrument==Xmm::EMOS1 ? 1 : 2;	// need always EMOS1
	Table *table = set->addTable("BORESIGHT", N);
	std::vector<unsigned long> size(1); size[0] = 5;

	char *_id = table->addColumn("INSTRUMENT_ID", Dal::DString, "", "", size)->
			data()->stringData();
	real64 *phi = table->addColumn("EULER_PHI", Dal::Real64, "rad")
				->data()->real64Data(),
		    *theta = table->addColumn("EULER_THETA", Dal::Real64, "rad")
				->data()->real64Data(),
			*psi = table->addColumn("EULER_PSI", Dal::Real64, "rad")
				->data()->real64Data();

	std::strncpy(_id, Xmm::toString(instrument).c_str(), 5);
	*phi = bsAngles.phi();
	*theta = bsAngles.theta();
	*psi = bsAngles.psi();
	if (N>1) {
		//	d/f EMOS1 entry
		std::strncpy(_id+5, Xmm::toString(Xmm::EMOS1).c_str(), 5);
		phi[1] = M_PI;
		theta[1] = 0.;
		psi[1] = 0.;
	}

	dataSetServer->close(set);
} // BoresightCcf::createAndFinalize()
