// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	BoresightCcf.h: - generate Boresight CCF constituent
//
//	DESCRIPTIONS:
//		Class to generate a Boresight CCF with a single entry for a
//		given instrument; to be used to override default constituent
//		in the CIF for the purpose of epicbscalgen - only the minimum
//		amount of required info is written to the data set.
//
//	
//	CHANGE HISTORY:
//		UL, 2003-05-23: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers, Fri May 23 17:50:08 MEST 2003
//
//	REFERENCES:
//		[1]: XMM Star Tracker/Instrument Alignment Calibration - Interface
//			 Control Document, Issue 1.2, R. Mugellesi, ESOC/ESA
//			 Online: ftp://astro.estec.esa.nl/pub/XMM/documents/
//					 siam_icd.pdf
//
//	$Header: /sasbuild/sas_git_repo/cvs_copy/sasdev/sas/packages/ccftools/bscalgen/src/BoresightCcf.h,v 1.1 2003/05/23 16:26:14 ulammers Exp $
//
#ifndef BORESIGHT_CCF
#define BORESIGHT_CCF

#include "Dal.h"
#include "Celestial.h"
#include "Xmm.h"

class BoresightCcf {
public:
	BoresightCcf(const string &name) : _name(name) {}

	void createAndFinalize(Xmm::Instrument instrument,
						   const EulerAngles &BSeulerAngles);

	~BoresightCcf() {}

private:
	string	_name;
	Table	*_table;
	char	*_id;
	real64	*_phi, *_theta, *_psi;
};

#endif
