// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Giuseppe Vacanti, November 1999
//
// Dirty task to stitch up CCF constituents.
//
#include <string>
#include <vector>

#include <Dal.h>
#include <Tracer.h>
#include <errstr.h>
#include <param.h>

#include <STime.h>

#include "ccfextseq.h"

void ccfextseq ()
{
  PROC

  using namespace std;

  STime now("now");

  vector<string> sets = stringListParameter("sets");
  bool production = booleanParameter("production");

  for (unsigned j = 0; j < sets.size(); j++) {    
    vector<string> names;    
    DataSet* set = dataSetServer->open(sets[j], Dal::Modify);
    for (unsigned i = 0; i < set->blocks(); i++) {
      names.push_back(set->block(i)->name());
    }
    string extsequ, extseqid;
    extsequ = "ANY";
    cout << "Processing: " << sets[j] << endl;
    cout << "The following extensions were found: " << endl;
    for (unsigned i = 0; i < names.size() ; i++) {
      cout << "      " << i << " " << names[i] << endl;
      extseqid += (names[i] + " ");
    }
    *set->addAttribute("EXTSEQID") = extseqid;
    *set->addAttribute("EXTSEQU") = extsequ;
    cout << "Start of validity date: "
	 << set->attribute("VALDATE")->asString() << endl;
    cout << "Issue: "
	 << set->attribute("ISSUE")->asString() << endl;
    STime sv(set->attribute("VALDATE")->asString());
    if(set->hasAttribute("SUBDATE"))
      set->deleteAttribute("SUBDATE");
    *set->addAttribute("SUBDATE") = now.toString(0).c_str();
    cout << "Submission date: "
	 << now.toString(0) << endl;
    if(set->hasAttribute("EVALDATE")){
      string evldate = set->attribute("EVALDATE")->asString();
      if(evldate == ""){
	set->deleteAttribute("EVALDATE");
	cout << "End of validity date: none" << endl;
      } else {
	STime ev(evldate);
	cout << "End of validity date: " << ev.toString(0) << endl;
	if(sv >= ev)
	  Sas::error("InconsistentDates", "VALDATE >= EVALDATE");
      }
    } else 
      cout << "End of validity date: none" << endl;
    if(production)
      *set->addAttribute("ORIGIN") = "XMM-Newton SOC, European Space Agency";
//      if(set->hasAttribute("CREATOR"))
//        set->deleteAttribute("CREATOR");
//      *set->addAttribute("CREATOR") = "deceit";

    dataSetServer->close(set);
  }

  ENDPROC
}
