// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	camtochip: CAMCOORD{1|2} to CHIPCOORD coordinates conversion
//
//	USAGE:
//		camtochip x=<x> y=<y> camcoordtype=1|2|DETXY
//							  instrument=EMOS1|EMOS2|EPN|RGS1|RGS2|OM
//
//		camcoordtype=1|2	: x/y provided in [mm]
//					=DETXY	: x/y provided in 0.05"
//
#include <iostream>
#include <iomanip>

#include "CalServer.h"
#include "GeometryDataServer.h"
#include "MiscDataServer.h"
#include "param.h"
#include "stringutil.h"

#include "camtochip.h"

void camtochip()
{
	string instrString(stringParameter("instrument"));
    calServer.setInstrument(Xmm::toInstrument(instrString));

	GeometryDataServer *gds = 0; gds = calServer.getAtom(gds);
	double x=realParameter("x"), x0=x,
		   y=realParameter("y"), y0=y,
		   z=0.;

	int camId = 0;
	if (stringParameter("camcoordtype") == "DETXY") {
		//	convert 0.05" DETX/Y to mm
		MiscDataServer *miscData = 0; miscData = calServer.getAtom(miscData);
		x *= .05 * miscData->get("MM_PER_PIXEL_X")
									/miscData->get("PLATE_SCALE_X");
		y *= .05 * miscData->get("MM_PER_PIXEL_Y")
									/miscData->get("PLATE_SCALE_Y");
		camId = 2;
	}

	CalReal64Vector xv(&x, 1),
					yv(&y, 1),
					zv(&z, 1);
	if (!camId)
		camId = toNumber<int>(stringParameter("camcoordtype"));
	XmmCartesianPointList cpl(
		camId == 1 ? gds->camCoord1List(xv, yv, zv)
				   : gds->camCoord2List(xv, yv, zv));

	if (camId == 2)
		cpl.toCamCoord1();

	vector<Ccd> ccd = cpl.onCcd();
	XmmPixelList ccl = cpl.toChipCoord();

	cout<<setw(5)<<instrString<<": CAMCOORD"<<camId<<"("<<x0<<", "<<y0
		<<") = CHIPCOORD("<<ccd[0]<<", "<<ccl.x()[0]<<", "<<ccl.y()[0]
		<<")\n";
}


