// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	CcdDataReader.h --- class to read CCD data
//
//	CHANGE HISTORY:
//		UL, 1999-07-01: 1.0.0: - first working version
//
//	AUTHOR:
//		U. Lammers, Fri Jul  2 11:54:39 MET DST 1999

#include <iomanip>
#include <iostream>
#include "Celestial.h"
#include "errstr.h"
#include "stringutil.h"

#ifndef CALDATAREADER_H
#define CALDATAREADER_H

struct CcdData {
	CartesianVector	A, B, C, D;
	unsigned		id;
};

class CcdDataReader {
public:
	CcdDataReader(istream &is) : _is(is), _isValid(false) { getNextSet(); }

	bool hasMore()
	{
		if (_isValid)
			return true;

		getNextSet();
		return _isValid;
	}

	CcdData get()
	{
		if (!_isValid)
			errstr<<"No more data sets"<<Sas::error("EndOfStream");

		CcdData d = _ccdData;
		getNextSet();
		return d;
	}

private:
	istream &_is;
	CcdData	_ccdData;
	bool	_isValid;

	void getNextSet() {
		char buff[128];

		_ccdData.id = 0;
		while(_is.getline(buff, 128, '\n')) {
			vector<string> v(breakup(buff));
			if (v.size() != 5 || lowercase(v[0].substr(0, 3)) != "ccd")
				continue;

			string ccdId = v[0];
			_ccdData.id = toNumber<unsigned>(v[0].substr(3, v[0].length()-3));
			assert(uppercase(v[1]) == "A");
			_ccdData.A = CartesianVector(toNumber<double>(v[4]),
										 toNumber<double>(v[3]),
										 -toNumber<double>(v[2]));
			#define NL(POINT) \
				if (_is.getline(buff, 128, '\n')) {			\
					vector<string> v(breakup(buff));		\
					assert(v.size() == 5 && v[0] == ccdId);	\
					assert(uppercase(v[1]) == #POINT);		\
					_ccdData.POINT = CartesianVector(toNumber<double>(v[4]), \
													 toNumber<double>(v[3]), \
													 -toNumber<double>(v[2]));\
				}

			NL(B); NL(C); NL(D);
			#undef NL

			_isValid = true;
			return;
		}
		_isValid = false;
	}
	
};

#endif
