// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//					   (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	LinCoord.h --- class to write LinCoord records
//
//	CHANGE HISTORY:
//		UL, 1999-07-01: 1.0.0: - first working version
//		UL, 1999-09-30: 2.0.0: - RAWX0/RAWX0 are now unsigned;
//
//	AUTHOR:
//		U. Lammers, Fri Jul  2 11:54:39 MET DST 1999

#include <iomanip>
#include <iostream>

#ifndef LINCOORD_H
#define LINCOORD_H

class LinCoord {
public:
	static void lineout(unsigned ccd, unsigned node, const CartesianVector &o,
						const EulerAngles &ea,
						unsigned rawX0, double rawY0)
	{
		cout<<ccd<<" "<<node<<" "
			//	origin + errors
			<<setprecision(8)<<o.x()<<" "<<o.y()<<" "<<o.z()<<" 0 0 0 "
			//	3-1-3 angles + errors
			<<setprecision(15)<<ea.phi()<<" "<<ea.theta()<<" "<<ea.psi()
			<<" 0 0 0 "
			//	ref. pixel
			<<rawX0<<" "<<rawY0<<endl;
	}

	static void header(const string &name)
	{
		cout<<"#\n";
		cout<<"# This file was automatically generated by `"<<name<<"'\n";
		cout<<"# DO NOT EDIT!\n";
		cout<<"#\n";
	}
};

#endif
